@@ -100,14 +100,20 @@ void InvoiceOperations::createDirectoryFile(
 
     QTextStream out(&directoryFile);
 
-    // .directory 
+    // [Desktop Entry] - freedesktop.org standard fields
     out << "[Desktop Entry]\n";
     out << "Type=Directory\n";
+    out << "Name=" << invoiceNumber << " - " << sender << "\n";
+    out << "Name[de]=" << invoiceNumber << " - " << sender << "\n";
+    out << "GenericName=Invoice\n";
+    out << "GenericName[de]=Eingangsrechnung\n";
+    out << "Comment=Invoice " << invoiceNumber << " from " << sender << " (" << receiptStamp << ")\n";
+    out << "Comment[de]=Rechnung " << invoiceNumber << " von " << sender << " (" << receiptStamp << ")\n";
     out << "Icon=" << folderIcon << "\n";
-    out << "Comment=Invoice: " << invoiceNumber << " from " << sender << "\n";
+    out << "Keywords=" << sender << ";" << invoiceNumber << ";" << budgetCode << ";Invoice;Rechnung;\n";
 
-    // [invoice] section
-    out << "\n[invoice]\n";
+    // [X-XRDialog-Invoice] - vendor-specific invoice data
+    out << "\n[X-XRDialog-Invoice]\n";
     out << "FormatVersion=1.0\n";
     out << "ReceiptDate=" << receiptStamp << "\n";
     out << "IssueDate=" << date << "\n";
@@ -119,13 +125,12 @@ void InvoiceOperations::createDirectoryFile(
         out << "PayableCurrency=EUR\n";
     }
 
-    // [p]rocessing] section
-    out << "\n[processing]\n";
+    // [X-XRDialog-Processing] - vendor-specific processing data
+    out << "\n[X-XRDialog-Processing]\n";
     out << "CreatedAt=" << QDateTime::currentDateTime().toString(Qt::ISODate) << "\n";
     out << "ProcessedBy=" << user << "\n";
     out << "Reviewed=" << (reviewed ? "true" : "false") << "\n";
     if (!comment.isEmpty()) {
-        // !FIXME! Maybe in *.txt file only in future?
         out << "Note=" << comment << "\n";
     }
 
@@ -227,12 +232,11 @@ bool InvoiceOperations::invoiceNumberExists(const QString &targetBasePath, const
     }
 
     // Read invoice ID from .directory files instead of parsing folder names
-    // This is more reliable since folder names may contain underscores in sender names (!FIXME! Test-> Does it **WORK**?)
     QStringList entries = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
     for (const QString &entry : entries) {
         QString directoryFile = targetBasePath + "/" + entry + "/.directory";
         QSettings settings(directoryFile, QSettings::IniFormat);
-        settings.beginGroup("invoice");
+        settings.beginGroup("X-XRDialog-Invoice");
         QString existingId = settings.value("ID", "").toString();
         settings.endGroup();
 
@@ -289,8 +293,8 @@ QVariantMap InvoiceOperations::loadInvoiceMetadata(const QString &filePath)
 
     QSettings settings(directoryFile, QSettings::IniFormat);
 
-    // Check if this is an invoice directory (has [invoice] section)
-    settings.beginGroup("invoice");
+    // Check if this is an invoice directory (has [X-XRDialog-Invoice] section)
+    settings.beginGroup("X-XRDialog-Invoice");
     if (!settings.contains("ID")) {
         settings.endGroup();
         return result;
@@ -306,7 +310,7 @@ QVariantMap InvoiceOperations::loadInvoiceMetadata(const QString &filePath)
     settings.endGroup();
 
     // Load processing data
-    settings.beginGroup("processing");
+    settings.beginGroup("X-XRDialog-Processing");
     result["processedBy"] = settings.value("ProcessedBy", "").toString();
     result["reviewed"] = settings.value("Reviewed", "false").toString() == "true";
     result["note"] = settings.value("Note", "").toString();
@@ -342,7 +346,7 @@ bool InvoiceOperations::updateInvoiceMetadata(
     QSettings oldSettings(directoryFilePath, QSettings::IniFormat);
     QStringList changes;
 
-    oldSettings.beginGroup("invoice");
+    oldSettings.beginGroup("X-XRDialog-Invoice");
     QString oldReceiptDate = oldSettings.value("ReceiptDate", "").toString();
     QString oldIssueDate = oldSettings.value("IssueDate", "").toString();
     QString oldSeller = oldSettings.value("Seller", "").toString();
@@ -351,7 +355,7 @@ bool InvoiceOperations::updateInvoiceMetadata(
     QString oldAmount = oldSettings.value("PayableAmount", "").toString();
     oldSettings.endGroup();
 
-    oldSettings.beginGroup("processing");
+    oldSettings.beginGroup("X-XRDialog-Processing");
     bool oldReviewed = oldSettings.value("Reviewed", "false").toString() == "true";
     QString oldNote = oldSettings.value("Note", "").toString();
     oldSettings.endGroup();
@@ -374,14 +378,20 @@ bool InvoiceOperations::updateInvoiceMetadata(
 
     QTextStream out(&directoryFile);
 
-    // Desktop Entry section (freedesktop.org standard)
+    // [Desktop Entry] - freedesktop.org standard fields
     out << "[Desktop Entry]\n";
     out << "Type=Directory\n";
+    out << "Name=" << invoiceNumber << " - " << sender << "\n";
+    out << "Name[de]=" << invoiceNumber << " - " << sender << "\n";
+    out << "GenericName=Invoice\n";
+    out << "GenericName[de]=Eingangsrechnung\n";
+    out << "Comment=Invoice " << invoiceNumber << " from " << sender << " (" << receiptStamp << ")\n";
+    out << "Comment[de]=Rechnung " << invoiceNumber << " von " << sender << " (" << receiptStamp << ")\n";
     out << "Icon=" << folderIcon << "\n";
-    out << "Comment=Invoice: " << invoiceNumber << " from " << sender << "\n";
+    out << "Keywords=" << sender << ";" << invoiceNumber << ";" << budgetCode << ";Invoice;Rechnung;\n";
 
-    // Invoice data section
-    out << "\n[invoice]\n";
+    // [X-XRDialog-Invoice] - vendor-specific invoice data
+    out << "\n[X-XRDialog-Invoice]\n";
     out << "FormatVersion=1.0\n";
     out << "ReceiptDate=" << receiptStamp << "\n";
     out << "IssueDate=" << date << "\n";
@@ -393,8 +403,8 @@ bool InvoiceOperations::updateInvoiceMetadata(
         out << "PayableCurrency=EUR\n";
     }
 
-    // Processing section
-    out << "\n[processing]\n";
+    // [X-XRDialog-Processing] - vendor-specific processing data
+    out << "\n[X-XRDialog-Processing]\n";
     out << "UpdatedAt=" << QDateTime::currentDateTime().toString(Qt::ISODate) << "\n";
     out << "ProcessedBy=" << user << "\n";
     out << "Reviewed=" << (reviewed ? "true" : "false") << "\n";
@@ -409,3 +419,31 @@ bool InvoiceOperations::updateInvoiceMetadata(
 
     return true;
 }
+
+QString InvoiceOperations::getNextVersionedFilename(const QString &folderPath, const QString &baseName)
+{
+    QString baseFilePath = folderPath + "/" + baseName + ".pdf";
+
+    // If base file doesn't exist, return it
+    if (!QFile::exists(baseFilePath)) {
+        return baseName;
+    }
+
+    // Find the next available version number
+    int version = 2;
+    while (true) {
+        QString versionedName = QString("%1_v%2").arg(baseName).arg(version);
+        QString versionedPath = folderPath + "/" + versionedName + ".pdf";
+
+        if (!QFile::exists(versionedPath)) {
+            return versionedName;
+        }
+
+        version++;
+
+        // Safety limit to prevent infinite loop !FIXME! Better solution needed
+        if (version > 999) {
+            return QString("%1_v%2").arg(baseName).arg(QDateTime::currentDateTime().toSecsSinceEpoch());
+        }
+    }
+}
